var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
/**
 * Return props for creating a [[Day]] component.
 */
export function getDayProps(day, modifiers, props) {
    var classNames = props.classNames, modifiersClassNames = props.modifiersClassNames, modifiersStyles = props.modifiersStyles, onDayClick = props.onDayClick, styles = props.styles;
    var onClick;
    if (modifiers.interactive && onDayClick) {
        onClick = function (e) {
            e.stopPropagation();
            e.preventDefault();
            onDayClick(day, modifiers, e);
        };
    }
    var style = __assign({}, styles === null || styles === void 0 ? void 0 : styles.day);
    if (styles) {
        // Apply the custom inline-styles
        Object.keys(modifiers).forEach(function (modifier) {
            style = __assign(__assign({}, style), styles[modifier]);
        });
    }
    if (modifiersStyles) {
        // Apply the styles for the modifier
        Object.keys(modifiers).forEach(function (modifier) {
            style = __assign(__assign({}, style), modifiersStyles[modifier]);
        });
    }
    var className = [];
    if (classNames && classNames.day) {
        className.push(classNames.day);
        if (modifiersClassNames) {
            Object.keys(modifiers)
                .filter(function (modifier) { return !!modifiers[modifier]; })
                .forEach(function (modifier) {
                if (modifier && classNames[modifier]) {
                    className.push(classNames[modifier]);
                }
                if (modifiersClassNames && modifiersClassNames[modifier]) {
                    className.push(modifiersClassNames[modifier]);
                }
            });
        }
    }
    var dataProps = {};
    Object.entries(modifiers)
        .filter(function (value) { return Boolean(value); })
        .forEach(function (_a) {
        var modifier = _a[0], value = _a[1];
        dataProps["data-rdp-" + modifier] = value;
    });
    var containerProps = __assign({ 'aria-disabled': !modifiers.interactive || undefined, 'aria-hidden': !modifiers.hidden || undefined, disabled: Boolean(modifiers.disabled) || undefined, onClick: onClick,
        style: style, className: className.join(' ') }, dataProps);
    var wrapperProps = {
        className: classNames === null || classNames === void 0 ? void 0 : classNames.dayWrapper,
        styles: styles === null || styles === void 0 ? void 0 : styles.dayWrapper
    };
    return { containerProps: containerProps, wrapperProps: wrapperProps, modifiers: modifiers };
}
//# sourceMappingURL=getDayProps.js.map