/**
 * Return props for creating a [[MonthCaption]] component.
 *
 * #### Usage
 *
 * Use this helper when swizzling the caption using the
 * [[DayPickerProps.components]] prop.
 *
 * ```jsx
 * function MonthCaption({ dayPickerProps }): JSX.Element {
 *   const { containerProps } = getCaptionProps(dayPickerProps);
 *   return (
 *     <caption {...containerProps}>
 *       Something inside the caption
 *     </caption>;
 *   )
 * }
 * <DayPicker swizzle={{ MonthCaption }} />
 * ```
 */
export function getCaptionProps(dayPickerProps) {
    var styles = dayPickerProps.styles, classNames = dayPickerProps.classNames;
    return {
        containerProps: {
            className: classNames === null || classNames === void 0 ? void 0 : classNames.caption,
            style: styles === null || styles === void 0 ? void 0 : styles.caption
        }
    };
}
//# sourceMappingURL=getCaptionProps.js.map