/// <reference types="react" />
import * as DateFns from 'date-fns';
import { DayPickerProps } from '../components/DayPicker';
/** Props to attach to the `DayPicker` component */
export declare type UseInputDayPickerProps = {
    onMonthChange: DayPickerProps['onMonthChange'];
    onDayClick: DayPickerProps['onDayClick'];
};
/** Props to attach to the `input` HTML element */
export declare type UseInputInputProps = {
    value: JSX.IntrinsicElements['input']['value'];
    onFocus: JSX.IntrinsicElements['input']['onFocus'];
    onBlur: JSX.IntrinsicElements['input']['onBlur'];
    onChange: JSX.IntrinsicElements['input']['onChange'];
};
/**
 * Hook to bind a input with a calendar.
 *
 * ```jsx
 * const {
 *  month,
 *  selected,
 *  dayPickerProps,
 *  inputProps
 * } = useInput(new Date());
 *
 * <DayPicker {...dayPickerProps} />
 * <input {...inputProps} />
 * ```
 */
export declare function useInput(initialSelectedDay: Date | undefined, formatStr: string, options: {
    locale: DateFns.Locale;
    required: boolean;
}): {
    month: Date;
    selected: Date | undefined;
    dayPickerProps: UseInputDayPickerProps;
    inputProps: UseInputInputProps;
};
